==> haskell-managed-1.0.5-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: managed
version: 1.0.5
id: managed-1.0.5-ETX2O5Y4l5T1QoOt8IFXQz
key: managed-1.0.5-ETX2O5Y4l5T1QoOt8IFXQz
license: BSD3
copyright: 2014 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.
    .
    The reason this package defines a specialized version of these types is to:
    .
    * be more beginner-friendly,
    .
    * simplify inferred types and error messages, and:
    .
    * provide some additional type class instances that would otherwise be orphan
    instances
category: Control
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Control.Monad.Managed Control.Monad.Managed.Safe
abi: b963a34048d45c5403749d50a3c4e45c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/managed-1.0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/managed-1.0.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/managed-1.0.5
hs-libraries: HSmanaged-1.0.5-ETX2O5Y4l5T1QoOt8IFXQz
depends:
    base-4.9.0.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html: /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-managed-1.0.5-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: managed
version: 1.0.5
id: managed-1.0.5-83xU3i5xYzoBicHocI7GYo
key: managed-1.0.5-83xU3i5xYzoBicHocI7GYo
license: BSD3
copyright: 2014 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.
    .
    The reason this package defines a specialized version of these types is to:
    .
    * be more beginner-friendly,
    .
    * simplify inferred types and error messages, and:
    .
    * provide some additional type class instances that would otherwise be orphan
    instances
category: Control
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Control.Monad.Managed Control.Monad.Managed.Safe
abi: 4f20f720dcfb8dff2a09706c0d8d4504
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/managed-1.0.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/managed-1.0.5
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/managed-1.0.5
hs-libraries: HSmanaged-1.0.5-83xU3i5xYzoBicHocI7GYo
depends:
    base-4.9.1.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html: /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
